@@ -11,11 +11,10 @@
 	 * pseudo in the child process
 	 */
 	if (rc == 0) {
-		if (!pseudo_get_value("PSEUDO_RELOADED")) {
-			pseudo_setupenv();
+		pseudo_setupenv();
+		if (!pseudo_get_value("PSEUDO_UNLOAD")) {
 			pseudo_reinit_libpseudo();
 		} else {
-			pseudo_setupenv();
 			pseudo_dropenv();
 		}
 	}
